@@ -9,8 +9,7 @@ from function_scheduling_distributed_framework.publishers.httpsqs_publisher impo
 
 class HttpsqsConsumer(AbstractConsumer):
     """
-    redis作为中间件实现的，使用redis list 结构实现的。
-    这个如果消费脚本在运行时候随意反复重启或者非正常关闭或者消费宕机，会丢失大批任务。高可靠需要用rabbitmq或者redis_ack_able或者redis_stream的中间件方式。
+    httpsqs作为中间件
     """
     BROKER_KIND = 18
 
