@@ -18,7 +18,8 @@ class MongoMqConsumer(AbstractConsumer, MongoMixin):
         while True:
             job = mp.queue.next()
             if job is not None:
-                self.logger.debug(f'从mongo的 [{self._queue_name}] 队列中 取出的消息是：   消息是：  {job.payload}  ')
+                # self.logger.debug(f'从mongo的 [{self._queue_name}] 队列中 取出的消息是：   消息是：  {job.payload}  ')
+                self._print_message_get_from_broker('mongo',job.payload)
                 kw = {'body': job.payload, 'job': job}
                 self._submit_task(kw)
             else:
