@@ -139,14 +139,13 @@ if __name__ == '__main__':
     app.run(debug=True, threaded=True, host='0.0.0.0', port=27018)
 
     '''
-    1、win上这么做
-    # 第一步 export PYTHONPATH=你的项目根目录 ，这么做是为了这个web可以读取到你项目根目录下的distributed_frame_config.py里面的配置
-    # 例如 export PYTHONPATH=./   (./是相对路径，前提是已近cd到你的项目根目录了，也可以写绝对路径全路径)
-    # 第二步   python3 -m function_scheduling_distributed_framework.function_result_web.app 
-    
-    
-    2、linux上可以这么做性能好一些，也可以按1的做
     # 第一步 export PYTHONPATH=你的项目根目录 ，这么做是为了这个web可以读取到你项目根目录下的distributed_frame_config.py里面的配置
     # 例如 export PYTHONPATH=/home/ydf/codes/ydfhome
-    # 第二步 gunicorn -w 4 --threads=30 --bind 0.0.0.0:27018 function_scheduling_distributed_framework.function_result_web.app:app
-    '''
\ No newline at end of file
+      或者  export PYTHONPATH=./   (./是相对路径，前提是已近cd到你的项目根目录了，也可以写绝对路径全路径)
+    
+    第二步   
+    win上这么做 python3 -m function_scheduling_distributed_framework.function_result_web.app 
+    
+    linux上可以这么做性能好一些，也可以按win的做。
+    gunicorn -w 4 --threads=30 --bind 0.0.0.0:27018 function_scheduling_distributed_framework.function_result_web.app:app
+    '''
