@@ -121,6 +121,7 @@ class PublishParamsChecker(LoggerMixin):
     def __init__(self, func: typing.Callable):
         # print(func)
         spec = inspect.getfullargspec(func)
+        self.all_arg_name = spec.args
         self.all_arg_name_set = set(spec.args)
         # print(spec.args)
         if spec.defaults:
@@ -146,17 +147,6 @@ class PublishParamsChecker(LoggerMixin):
                              f'必须是 {self.all_arg_name_set} 的子集， 必须是 {self.position_arg_name_set} 的超集')
 
 
-class DelayQueue(LoggerMixin, RedisMixin):
-    def __init__(self, delay_queue_name):
-        self.delay_queue_name = delay_queue_name
-
-    def push(self, msg: str, timestamp):
-        self.redis_db_frame_version3.zadd(self.delay_queue_name, {msg: timestamp}, )
-
-    def get_msgs(self):
-        pass
-
-
 class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
     def __init__(self, queue_name, log_level_int=10, logger_prefix='', is_add_file_handler=True,
@@ -265,8 +255,9 @@ class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         # print(self.publish_params_checker.position_arg_name_list)
         # print(func_args)
         for index, arg in enumerate(func_args):
-            # print(arg)
-            msg_dict[self.publish_params_checker.position_arg_name_list[index]] = arg
+            # print(index,arg,self.publish_params_checker.position_arg_name_list)
+            # msg_dict[self.publish_params_checker.position_arg_name_list[index]] = arg
+            msg_dict[self.publish_params_checker.all_arg_name[index]] = arg
         # print(msg_dict)
         return self.publish(msg_dict)
 
