@@ -11,6 +11,7 @@ import time
 import re
 import importlib
 from pathlib import Path
+from shutil import copyfile
 from nb_log import nb_print,stderr_write,stdout_write
 from nb_log.monkey_print import is_main_process,only_print_on_main_process
 from function_scheduling_distributed_framework import frame_config
@@ -72,66 +73,6 @@ def show_frame_config():
                 only_print_on_main_process(f'{var_name}:                {var_value}')
 
 
-config_file_content = '''# -*- coding: utf-8 -*-
-"""
-此文件是分布式函数调度框架第一次运行时候自动生成的，按需修改里面的配置项。
-比如你只用redis，把redis前面的 # 注释放开，修改成你的值，无需理会其他配置项如 rabbitmq  kafka。
-
-1.1） 此py配置文件的内容是可以不拘于形式的，例如在此文件里面可以根据环境写if else 判断，或者写其他python代码，里面写各种函数和变量都可以的。但模块必须按需包括以下名字的变量，
-例如 如果不使用rabbitmq作为中间件，只使用redis做中间件，则此模块可以没有RABBITMQ_USER RABBITMQ_PASS MOOGO KAFKA sql数据库等这些变量，只需要redis相关的变量就可以。
-
-1.2）如果你的py启动脚本是项目的深层目录下，你也可以在那个启动目录下，放入这个文件，
-框架会优先读取启动脚本所在目录的distributed_frame_config.py作为配置，
-如果启动脚本所在目录下无 distributed_frame_config.py 文件，则会使用项目根目录下的distributed_frame_config.py做配置。
-
-"""
-
-# 以下为配置，请按需修改。
-
-# MONGO_CONNECT_URL = f'mongodb://yourname:yourpassword@127.0.01:27017/admin'
-# 
-# RABBITMQ_USER = 'rabbitmq_user'
-# RABBITMQ_PASS = 'rabbitmq_pass'
-# RABBITMQ_HOST = '127.0.0.1'
-# RABBITMQ_PORT = 5672
-# RABBITMQ_VIRTUAL_HOST = 'rabbitmq_virtual_host'
-# 
-# REDIS_HOST = '127.0.0.1'
-# REDIS_PASSWORD = '' 
-# REDIS_PORT = 6379
-# REDIS_DB = 7
-# 
-# NSQD_TCP_ADDRESSES = ['127.0.0.1:4150']
-# NSQD_HTTP_CLIENT_HOST = '127.0.0.1'
-# NSQD_HTTP_CLIENT_PORT = 4151
-# 
-# KAFKA_BOOTSTRAP_SERVERS = ['127.0.0.1:9092']
-# 
-# SQLACHEMY_ENGINE_URL ='sqlite:////sqlachemy_queues/queues.db'
-
-# SQLLITE_QUEUES_PATH = '/sqllite_queues'  # 这里可以自定义persit_queue中间件模式的sqlite3的文件位置。
-
-# ROCKETMQ_NAMESRV_ADDR = '192.168.199.202:9876'
-
-# MQTT_HOST = '127.0.0.1'
-# MQTT_TCP_PORT = 1883
-
-# HTTPSQS_HOST = '127.0.0.1'
-# HTTPSQS_PORT = '1218'
-# HTTPSQS_AUTH = '123456'
-
-#KOMBU_URL = 'redis://127.0.0.1:6379/7' 那么就是使用komb 操作redis。
-#KOMBU_URL = 'amqp://username:password@127.0.0.1:5672/',那么就是操纵rabbitmq
-#KOMBU_URL = 'sqla+sqlite:////dssf_sqlite.sqlite',那么就是在你的代码所在磁盘的根目录创建一个sqlite文件。四个////表示根目，三个///表示当前目录。
-
-
-# nb_log包的第几个日志模板，内置了7个模板，可以在你当前项目根目录下的nb_log_config.py文件扩展模板。第5个模板可以点击跳转到框架内部，但有点占控制台面积，第7个模板简单不可点击跳转到框架内部。
-# NB_LOG_FORMATER_INDEX_FOR_CONSUMER_AND_PUBLISHER = 7     
-# FSDF_DEVELOP_LOG_LEVEL = 50   # 开发时候的日志，进攻自己用，所以日志级别跳到最高
-
-# TIMEZONE = 'Asia/Shanghai'          
-'''
-
 
 def use_config_form_distributed_frame_config_module():
     """
@@ -156,7 +97,7 @@ def use_config_form_distributed_frame_config_module():
         # import distributed_frame_config
         m = importlib.import_module('distributed_frame_config')
         # nb_print(m.__dict__)
-        only_print_on_main_process(f'分布式函数调度框架 读取到\n "{m.__file__}:1" 文件里面的变量作为配置了\n')
+        only_print_on_main_process(f'分布式函数调度框架 读取到\n "{m.__file__}:1" 文件里面的变量作为优先配置了\n')
         for var_namex, var_valuex in m.__dict__.items():
             if var_namex.isupper():
                 setattr(frame_config, var_namex, var_valuex)  # 用用户自定义的配置覆盖框架的默认配置。
@@ -183,13 +124,17 @@ def auto_creat_config_file_to_project_root_path():
     if '/lib/python' in sys.path[1] or r'\lib\python' in sys.path[1] or '.zip' in sys.path[1]:
         raise EnvironmentError('如果是cmd 或者shell启动而不是pycharm 这种ide启动脚本，请先在会话窗口设置临时PYTHONPATH为你的项目路径，'
                                'windwos 使用 set PYTHONNPATH=你的当前python项目根目录'
-                               'linux 使用 export PYTHONPATH=你的当前你python项目根目录')
+                               'linux 使用 export PYTHONPATH=你的当前你python项目根目录'
+                               'PYTHONPATH 作用是python的基本常识，请百度一下。'
+                               '需要在会话窗口命令行设置临时的环境变量，而不是修改linux配置文件的方式设置永久环境变量，每个python项目的PYTHONPATH都要不一样，不要在配置文件写死')
         return  # 当没设置pythonpath时候，也不要在 /lib/python36.zip这样的地方创建配置文件。
 
     file_name = Path(sys.path[1]) / Path('distributed_frame_config.py')
-    with (file_name).open(mode='w', encoding='utf8') as f:
-        nb_print(f'在 {file_name} 目录下自动生成了一个文件， 请查看或修改 \n "{file_name}:1" 文件')
-        f.write(config_file_content)
+    copyfile(Path(__file__).absolute().parent / Path('frame_config.py'),file_name)
+    nb_print(f'在  {Path(sys.path[1])} 目录下自动生成了一个文件， 请查看或修改 \n "{file_name}:1" 文件')
+    # with (file_name).open(mode='w', encoding='utf8') as f:
+    #     nb_print(f'在 {file_name} 目录下自动生成了一个文件， 请查看或修改 \n "{file_name}:1" 文件')
+    #     f.write(config_file_content)
 
 
 use_config_form_distributed_frame_config_module()
